// -*-c++-*-
// -----------------------------------------------------------
// This file is part of DRMAA-python.
// Copyright (C) 2005 StatPro Italia s.r.l. Milano 
// Copyright (C) 2004 The Regents of the University of California.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor,
// Boston, MA  02110-1301, USA.
// -----------------------------------------------------------
//  Author: Tim Harsch <harsch1@llnl.gov>
//          Lawrence Livermore National Laboratory, University of California
//  Modified for python by: Enrico Sirola <enrico.sirola@statpro.com>
//
//  $Id$
// -----------------------------------------------------------

%module "cDRMAA"

%include "typemaps.i"

%{
#include "drmaa.h"
%}

%typemap(in,numinputs=0) (char * error_diagnosis, size_t error_diag_len ) {
	$1 = (char*) malloc( sizeof(char) * DRMAA_ERROR_STRING_BUFFER );
	$2 = DRMAA_ERROR_STRING_BUFFER;
}
%apply (char * error_diagnosis, size_t error_diag_len ) { ( char *value, size_t value_len ) }
%typemap(in,numinputs=0) ( char *job_id, size_t job_id_len ) {
	$1 = (char*) malloc( sizeof(char) * DRMAA_JOBNAME_BUFFER );
	$2 = DRMAA_JOBNAME_BUFFER;
}
%apply (char *job_id, size_t job_id_len ) { ( char *job_id_out, size_t job_id_out_len ) }
%typemap(in,numinputs=0) ( char *drm_system, size_t drm_system_len ) {
	$1 = (char*) malloc( sizeof(char) * DRMAA_DRM_SYSTEM_BUFFER );
	$2 = DRMAA_DRM_SYSTEM_BUFFER;
}
%apply (char *drm_system, size_t drm_system_len ) { ( char *drmaa_impl, size_t drmaa_impl_len ) }
%typemap(in,numinputs=0) ( char *contact, size_t contact_len ) {
	$1 = (char*) malloc( sizeof(char) * DRMAA_CONTACT_BUFFER );
	$2 = DRMAA_CONTACT_BUFFER;
}
%typemap(in,numinputs=0) ( char *signal, size_t signal_len ) {
	$1 = (char*) malloc( sizeof(char) * DRMAA_SIGNAL_BUFFER );
	$2 = DRMAA_SIGNAL_BUFFER;
}

%typemap(argout) char *error_diagnosis {
    PyObject *o, *o2, *o3;
    o = PyString_FromString($1);
    if ((!$result) || ($result == Py_None)) {
        $result = o;
    } else {
        if (!PyTuple_Check($result)) {
            PyObject *o2 = $result;
            $result = PyTuple_New(1);
            PyTuple_SetItem($result,0,o2);
        }
        o3 = PyTuple_New(1);
        PyTuple_SetItem(o3,0,o);
        o2 = $result;
        $result = PySequence_Concat(o2,o3);
        Py_DECREF(o2);
        Py_DECREF(o3);
    }
}        

%apply char *error_diagnosis { char *value }
%apply char *error_diagnosis { char *job_id }
%apply char *error_diagnosis { char *job_id_out }
%apply char *error_diagnosis { char *contact }
%apply char *error_diagnosis { char *drm_system }
%apply char *error_diagnosis { char *drmaa_impl };

%typemap(argout) const char * "pass";

%typemap(in,numinputs=0) drmaa_job_template_t ** ( $*1_type keepme )  {
    keepme = NULL;
    
    $1 = &keepme;
}

%typemap(argout) drmaa_job_template_t ** {
    PyObject *o, *o2, *o3;
    o=SWIG_NewPointerObj(*$1, $*1_descriptor, 0);
    if ((!$result) || ($result == Py_None)) {
        $result = o;
    } else {
        if (!PyTuple_Check($result)) {
            PyObject *o2 = $result;
            $result = PyTuple_New(1);
            PyTuple_SetItem($result,0,o2);
        }
        o3 = PyTuple_New(1);
        PyTuple_SetItem(o3,0,o);
        o2 = $result;
        $result = PySequence_Concat(o2,o3);
        Py_DECREF(o2);
        Py_DECREF(o3);
    }
}

%apply drmaa_job_template_t ** { drmaa_job_ids_t ** }
%apply drmaa_job_template_t ** { drmaa_attr_names_t ** }
%apply drmaa_job_template_t ** { drmaa_attr_values_t ** }

// This tells SWIG to treat char ** as a special case
%typemap(in) const char *[] {
  /* Check if is a list */
  if (PyList_Check($input)) {
    int size = PyList_Size($input);
    int i = 0;
    $1 = (char **) malloc((size+1)*sizeof(char *));
    for (i = 0; i < size; i++) {
      PyObject *o = PyList_GetItem($input,i);
      if (PyString_Check(o))
	$1[i] = PyString_AsString(PyList_GetItem($input,i));
      else {
	PyErr_SetString(PyExc_TypeError,"list must contain strings");
	free($1);
	return NULL;
      }
    }
    $1[i] = 0;
  } else {
    PyErr_SetString(PyExc_TypeError,"not a list");
    return NULL;
  }
}

%apply unsigned int *OUTPUT { unsigned int * }
%apply int *OUTPUT { int * }

%include "drmaa.h"

