# -*- coding: iso-8859-1; mode: python -*-
# -----------------------------------------------------------
# This file is part of DRMAA-python.
# Copyright (C) 2005 StatPro Italia s.r.l. Milano 
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA  02110-1301, USA.
# -----------------------------------------------------------
#  Author: Enrico Sirola <enrico.sirola@statpro.com> 
# 
#  $Id$
# -----------------------------------------------------------

import os, sys, string
from distutils.cmd import Command
from distutils.command.install_data import install_data
from distutils.command.install import install
from distutils.command.sdist import sdist
from distutils.file_util import copy_file
from distutils.core import setup, Extension

SGE6_ROOT="/scratch_test02/SGE6"
SGE6_ARCH=os.popen(os.path.join(SGE6_ROOT,'util/arch')).read().strip()

swig_files = ['DRMAA.i']

# class taken from QuantLib's setup file
class my_wrap(Command):
    description = "generate Python wrappers"
    user_options = []
    def initialize_options(self): pass
    def finalize_options(self): pass
    def run(self):
        print "Generating Python bindings for DRMAA..."
        cmd = 'swig -python -modern ' + \
              "-I%s" % os.path.join(SGE6_ROOT, "include") + \
              ' -o cDRMAA_wrap.c ' + \
              'DRMAA.i'
        print cmd
        os.system(cmd)

compile_args = [ "-I%s" % os.path.join(SGE6_ROOT, "include")]
link_args = [ "-L%s" % os.path.join(SGE6_ROOT, "lib", SGE6_ARCH),  "-ldrmaa"  ]
define_macros = [ (arg[2:],None) for arg in compile_args
                                 if arg.startswith('-D') ]
include_dirs = [ arg[2:] for arg in compile_args
                         if arg.startswith('-I') ]
library_dirs = [ arg[2:] for arg in link_args
                         if arg.startswith('-L') ]
libraries = [ arg[2:] for arg in link_args
                      if arg.startswith('-l') ]
extra_compile_args = [ arg for arg in compile_args
                           if not arg.startswith('-D')
                           if not arg.startswith('-I') ] \
                   + [ '-Wno-unused' ]
extra_link_args = [ arg for arg in link_args
                        if not arg.startswith('-L')
                        if not arg.startswith('-l') ]

setup(name             = "DRMAA-python",
      version          = "0.2",
      description      = "Python bindings for the DRMAA library",
      long_description = """
      A python module for managing DRM using the DRMAA C API.
      """,
      author           = "Enrico Sirola",
      author_email     = "enrico.sirola@statpro.com",
      license          = "GPL",
      py_modules       = ['DRMAA','cDRMAA'],
      ext_modules      = [Extension("_cDRMAA",
                                    ["cDRMAA_wrap.c"],
                                    libraries = libraries,
                                    define_macros = define_macros,
                                    include_dirs = include_dirs,
                                    library_dirs = library_dirs,
                                    extra_compile_args = extra_compile_args,
                                    extra_link_args = extra_link_args)
                         ],
      cmdclass         = {'wrap': my_wrap}
      )
